import type { NextFunction, Request, Response } from 'express';
import { Options, Schema } from 'fast-json-stringify';
export type { Schema, Options } from 'fast-json-stringify';
/**
 * Set the schema
 * @param {Schema} schema The schema used to stringify values
 * @param {Options} options The options to use (optional)
 *
 * Examples:
 * ```ts
 * import express from 'express';
 * import { fastJsonSchemas, Schema } from 'express-fast-json-stringify';
 *
 * const app = express();
 *
 * const schema: Schema = {
 *   title: 'Example Schema',
 *   type: 'object',
 *   properties: {
 *     firstName: {
 *       type: 'string',
 *     },
 *     lastName: {
 *       type: 'string',
 *     },
 *     age: {
 *       type: 'integer',
 *     }
 *   },
 * };
 *
 * app.get('/', fastJsonSchema(schema), (req, res, next) => {
 *  try {
 *    const data = {
 *      firstName: "Simone",
 *      lastName: "Nigro",
 *      age: 40
 *    };
 *    res.fastJson(data);
 *  } catch (error) {
 *    next(error);
 *  }
 * });
 * ```
 */
export declare const fastJsonSchema: (schema: Schema, options?: Options) => (_req: Request, res: Response, next: NextFunction) => void;
